gui Package
===========

:mod:`app_admin` Module
-----------------------

.. automodule:: stoq.tests.gui.app_admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app_pos` Module
---------------------

.. automodule:: stoq.tests.gui.app_pos
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app_purchase` Module
--------------------------

.. automodule:: stoq.tests.gui.app_purchase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app_receivable` Module
----------------------------

.. automodule:: stoq.tests.gui.app_receivable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app_sales` Module
-----------------------

.. automodule:: stoq.tests.gui.app_sales
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`app_warehouse` Module
---------------------------

.. automodule:: stoq.tests.gui.app_warehouse
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`delivery` Module
----------------------

.. automodule:: stoq.tests.gui.delivery
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`salewizard` Module
------------------------

.. automodule:: stoq.tests.gui.salewizard
    :members:
    :undoc-members:
    :show-inheritance:

